labeltools.label_leaves_in_expr_with_pitch_numbers
==================================================

.. autofunction:: abjad.tools.labeltools.label_leaves_in_expr_with_pitch_numbers.label_leaves_in_expr_with_pitch_numbers
